Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(29)

Unified Diff: mandoline/ui/phone_ui/phone_browser_application_delegate.cc

Issue 1340983002: Mandoline UI Process: Update namespaces and file names (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebased Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mandoline/ui/phone_ui/phone_browser_application_delegate.h ('k') | mojo/cc/output_surface_mojo.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mandoline/ui/phone_ui/phone_browser_application_delegate.cc
diff --git a/mandoline/ui/phone_ui/phone_browser_application_delegate.cc b/mandoline/ui/phone_ui/phone_browser_application_delegate.cc
index 8897e906cde3dc9f9f3e7c7e97fd91eeabfbf962..616f0a78a8a28af870f6976377834b55eee89580 100644
--- a/mandoline/ui/phone_ui/phone_browser_application_delegate.cc
+++ b/mandoline/ui/phone_ui/phone_browser_application_delegate.cc
@@ -47,7 +47,7 @@ void PhoneBrowserApplicationDelegate::Initialize(mojo::ApplicationImpl* app) {
break;
}
}
- mojo::CreateSingleViewTreeHost(app_, this, &host_);
+ mus::CreateSingleViewTreeHost(app_, this, &host_);
}
bool PhoneBrowserApplicationDelegate::ConfigureIncomingConnection(
@@ -66,9 +66,9 @@ void PhoneBrowserApplicationDelegate::LaunchURL(const mojo::String& url) {
}
////////////////////////////////////////////////////////////////////////////////
-// PhoneBrowserApplicationDelegate, mojo::ViewTreeDelegate implementation:
+// PhoneBrowserApplicationDelegate, mus::ViewTreeDelegate implementation:
-void PhoneBrowserApplicationDelegate::OnEmbed(mojo::View* root) {
+void PhoneBrowserApplicationDelegate::OnEmbed(mus::View* root) {
CHECK(!root_);
root_ = root;
content_ = root->connection()->CreateView();
@@ -83,14 +83,13 @@ void PhoneBrowserApplicationDelegate::OnEmbed(mojo::View* root) {
}
void PhoneBrowserApplicationDelegate::OnConnectionLost(
- mojo::ViewTreeConnection* connection) {
-}
+ mus::ViewTreeConnection* connection) {}
////////////////////////////////////////////////////////////////////////////////
// PhoneBrowserApplicationDelegate, mojo::ViewObserver implementation:
void PhoneBrowserApplicationDelegate::OnViewBoundsChanged(
- mojo::View* view,
+ mus::View* view,
const mojo::Rect& old_bounds,
const mojo::Rect& new_bounds) {
CHECK_EQ(view, root_);
@@ -83,14 +83,13 @@ void PhoneBrowserApplicationDelegate::OnEmbed(mojo::View* root) {
////////////////////////////////////////////////////////////////////////////////
-// PhoneBrowserApplicationDelegate, mojo::ViewObserver implementation:
+// PhoneBrowserApplicationDelegate, mus::ViewObserver implementation:
void PhoneBrowserApplicationDelegate::OnViewBoundsChanged(
« no previous file with comments | « mandoline/ui/phone_ui/phone_browser_application_delegate.h ('k') | mojo/cc/output_surface_mojo.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698